==> bullet-docs-2.86-2-aarch64.pkg.tar.xz: usr/share/doc/bullet/html/menudata.js <==
var menudata={children:[
{text:"Main Page",url:"index.html"},
{text:"Namespaces",url:"namespaces.html",children:[
{text:"Namespace List",url:"namespaces.html"},
{text:"Namespace Members",url:"namespacemembers.html",children:[
{text:"All",url:"namespacemembers.html"},
{text:"Functions",url:"namespacemembers_func.html"},
{text:"Variables",url:"namespacemembers_vars.html"},
{text:"Typedefs",url:"namespacemembers_type.html"},
{text:"Enumerations",url:"namespacemembers_enum.html"},
{text:"Enumerator",url:"namespacemembers_eval.html"}]}]},
{text:"Classes",url:"annotated.html",children:[
{text:"Class List",url:"annotated.html"},
{text:"Class Hierarchy",url:"inherits.html"},
{text:"Class Members",url:"functions.html",children:[
{text:"All",url:"functions.html",children:[
{text:"_",url:"functions.html#index__"},
{text:"a",url:"functions_a.html#index_a"},
{text:"b",url:"functions_b.html#index_b"},
{text:"c",url:"functions_c.html#index_c"},
{text:"d",url:"functions_d.html#index_d"},
{text:"e",url:"functions_e.html#index_e"},
{text:"f",url:"functions_f.html#index_f"},
{text:"g",url:"functions_g.html#index_g"},
{text:"h",url:"functions_h.html#index_h"},
{text:"i",url:"functions_i.html#index_i"},
{text:"j",url:"functions_j.html#index_j"},
{text:"k",url:"functions_k.html#index_k"},
{text:"l",url:"functions_l.html#index_l"},
{text:"m",url:"functions_m.html#index_m"},
{text:"n",url:"functions_n.html#index_n"},
{text:"o",url:"functions_o.html#index_o"},
{text:"p",url:"functions_p.html#index_p"},
{text:"q",url:"functions_q.html#index_q"},
{text:"r",url:"functions_r.html#index_r"},
{text:"s",url:"functions_s.html#index_s"},
{text:"t",url:"functions_t.html#index_t"},
{text:"u",url:"functions_u.html#index_u"},
{text:"v",url:"functions_v.html#index_v"},
{text:"w",url:"functions_w.html#index_w"},
{text:"x",url:"functions_x.html#index_x"},
{text:"y",url:"functions_y.html#index_y"},
{text:"z",url:"functions_z.html#index_z"},
{text:"~",url:"functions_0x7e.html#index_0x7e"}]},
{text:"Functions",url:"functions_func.html",children:[
{text:"_",url:"functions_func.html#index__"},
{text:"a",url:"functions_func_a.html#index_a"},
{text:"b",url:"functions_func_b.html#index_b"},
{text:"c",url:"functions_func_c.html#index_c"},
{text:"d",url:"functions_func_d.html#index_d"},
{text:"e",url:"functions_func_e.html#index_e"},
{text:"f",url:"functions_func_f.html#index_f"},
{text:"g",url:"functions_func_g.html#index_g"},
{text:"h",url:"functions_func_h.html#index_h"},
{text:"i",url:"functions_func_i.html#index_i"},
{text:"j",url:"functions_func_j.html#index_j"},
{text:"l",url:"functions_func_l.html#index_l"},
{text:"m",url:"functions_func_m.html#index_m"},
{text:"n",url:"functions_func_n.html#index_n"},
{text:"o",url:"functions_func_o.html#index_o"},
{text:"p",url:"functions_func_p.html#index_p"},
{text:"q",url:"functions_func_q.html#index_q"},
{text:"r",url:"functions_func_r.html#index_r"},
{text:"s",url:"functions_func_s.html#index_s"},
{text:"t",url:"functions_func_t.html#index_t"},
{text:"u",url:"functions_func_u.html#index_u"},
{text:"v",url:"functions_func_v.html#index_v"},
{text:"w",url:"functions_func_w.html#index_w"},
{text:"x",url:"functions_func_x.html#index_x"},
{text:"y",url:"functions_func_y.html#index_y"},
{text:"z",url:"functions_func_z.html#index_z"},
{text:"~",url:"functions_func_0x7e.html#index_0x7e"}]},
{text:"Variables",url:"functions_vars.html",children:[
{text:"_",url:"functions_vars.html#index__"},
{text:"a",url:"functions_vars_a.html#index_a"},
{text:"b",url:"functions_vars_b.html#index_b"},
{text:"c",url:"functions_vars_c.html#index_c"},
{text:"d",url:"functions_vars_d.html#index_d"},
{text:"e",url:"functions_vars_e.html#index_e"},
{text:"f",url:"functions_vars_f.html#index_f"},
{text:"g",url:"functions_vars_g.html#index_g"},
{text:"h",url:"functions_vars_h.html#index_h"},
{text:"i",url:"functions_vars_i.html#index_i"},
{text:"j",url:"functions_vars_j.html#index_j"},
{text:"k",url:"functions_vars_k.html#index_k"},
{text:"l",url:"functions_vars_l.html#index_l"},
{text:"m",url:"functions_vars_m.html#index_m"},
{text:"n",url:"functions_vars_n.html#index_n"},
{text:"o",url:"functions_vars_o.html#index_o"},
{text:"p",url:"functions_vars_p.html#index_p"},
{text:"r",url:"functions_vars_r.html#index_r"},
{text:"s",url:"functions_vars_s.html#index_s"},
{text:"t",url:"functions_vars_t.html#index_t"},
{text:"u",url:"functions_vars_u.html#index_u"},
{text:"v",url:"functions_vars_v.html#index_v"},
{text:"w",url:"functions_vars_w.html#index_w"},
{text:"x",url:"functions_vars_x.html#index_x"},
{text:"y",url:"functions_vars_y.html#index_y"},
{text:"z",url:"functions_vars_z.html#index_z"}]},
{text:"Typedefs",url:"functions_type.html"},
{text:"Enumerations",url:"functions_enum.html",children:[
{text:"_",url:"functions_enum.html#index__"},
{text:"a",url:"functions_enum.html#index_a"},
{text:"b",url:"functions_enum.html#index_b"},
{text:"c",url:"functions_enum.html#index_c"},
{text:"d",url:"functions_enum.html#index_d"},
{text:"e",url:"functions_enum.html#index_e"},
{text:"f",url:"functions_enum.html#index_f"},
{text:"o",url:"functions_enum.html#index_o"},
{text:"s",url:"functions_enum.html#index_s"}]},
{text:"Enumerator",url:"functions_eval.html",children:[
{text:"a",url:"functions_eval.html#index_a"},
{text:"b",url:"functions_eval.html#index_b"},
{text:"c",url:"functions_eval.html#index_c"},
{text:"d",url:"functions_eval.html#index_d"},
{text:"e",url:"functions_eval.html#index_e"},
{text:"f",url:"functions_eval.html#index_f"},
{text:"g",url:"functions_eval.html#index_g"},
{text:"i",url:"functions_eval.html#index_i"},
{text:"j",url:"functions_eval.html#index_j"},
{text:"k",url:"functions_eval.html#index_k"},
{text:"l",url:"functions_eval.html#index_l"},
{text:"n",url:"functions_eval.html#index_n"},
{text:"o",url:"functions_eval.html#index_o"},
{text:"p",url:"functions_eval.html#index_p"},
{text:"r",url:"functions_eval.html#index_r"},
{text:"s",url:"functions_eval.html#index_s"},
{text:"t",url:"functions_eval.html#index_t"},
{text:"v",url:"functions_eval.html#index_v"}]},
{text:"Related Functions",url:"functions_rela.html"}]}]},
{text:"Files",url:"files.html",children:[
{text:"File List",url:"files.html"},
{text:"File Members",url:"globals.html",children:[
{text:"All",url:"globals.html",children:[
{text:"_",url:"globals.html#index__"},
{text:"a",url:"globals_a.html#index_a"},
{text:"b",url:"globals_b.html#index_b"},
{text:"c",url:"globals_c.html#index_c"},
{text:"d",url:"globals_d.html#index_d"},
{text:"e",url:"globals_e.html#index_e"},
{text:"f",url:"globals_f.html#index_f"},
{text:"g",url:"globals_g.html#index_g"},
{text:"h",url:"globals_h.html#index_h"},
{text:"i",url:"globals_i.html#index_i"},
{text:"k",url:"globals_k.html#index_k"},
{text:"l",url:"globals_l.html#index_l"},
{text:"m",url:"globals_m.html#index_m"},
{text:"n",url:"globals_n.html#index_n"},
{text:"o",url:"globals_o.html#index_o"},
{text:"p",url:"globals_p.html#index_p"},
{text:"q",url:"globals_q.html#index_q"},
{text:"r",url:"globals_r.html#index_r"},
{text:"s",url:"globals_s.html#index_s"},
{text:"t",url:"globals_t.html#index_t"},
{text:"u",url:"globals_u.html#index_u"},
{text:"v",url:"globals_v.html#index_v"},
{text:"w",url:"globals_w.html#index_w"},
{text:"x",url:"globals_x.html#index_x"},
{text:"y",url:"globals_y.html#index_y"},
{text:"z",url:"globals_z.html#index_z"}]},
{text:"Functions",url:"globals_func.html",children:[
{text:"_",url:"globals_func.html#index__"},
{text:"a",url:"globals_func_a.html#index_a"},
{text:"b",url:"globals_func_b.html#index_b"},
{text:"c",url:"globals_func_c.html#index_c"},
{text:"d",url:"globals_func_d.html#index_d"},
{text:"e",url:"globals_func_e.html#index_e"},
{text:"f",url:"globals_func_f.html#index_f"},
{text:"g",url:"globals_func_g.html#index_g"},
{text:"h",url:"globals_func_h.html#index_h"},
{text:"i",url:"globals_func_i.html#index_i"},
{text:"l",url:"globals_func_l.html#index_l"},
{text:"m",url:"globals_func_m.html#index_m"},
{text:"n",url:"globals_func_n.html#index_n"},
{text:"o",url:"globals_func_o.html#index_o"},
{text:"p",url:"globals_func_p.html#index_p"},
{text:"q",url:"globals_func_q.html#index_q"},
{text:"r",url:"globals_func_r.html#index_r"},
{text:"s",url:"globals_func_s.html#index_s"},
{text:"t",url:"globals_func_t.html#index_t"},
{text:"v",url:"globals_func_v.html#index_v"},
{text:"z",url:"globals_func_z.html#index_z"}]},
{text:"Variables",url:"globals_vars.html",children:[
{text:"b",url:"globals_vars.html#index_b"},
{text:"d",url:"globals_vars.html#index_d"},
{text:"g",url:"globals_vars.html#index_g"},
{text:"i",url:"globals_vars.html#index_i"},
{text:"m",url:"globals_vars.html#index_m"},
{text:"n",url:"globals_vars.html#index_n"},
{text:"p",url:"globals_vars.html#index_p"},
{text:"s",url:"globals_vars.html#index_s"},
{text:"u",url:"globals_vars.html#index_u"},
{text:"v",url:"globals_vars.html#index_v"}]},
{text:"Typedefs",url:"globals_type.html",children:[
{text:"b",url:"globals_type.html#index_b"},
{text:"c",url:"globals_type.html#index_c"},
{text:"d",url:"globals_type.html#index_d"},
{text:"g",url:"globals_type.html#index_g"},
{text:"h",url:"globals_type.html#index_h"},
{text:"i",url:"globals_type.html#index_i"},
{text:"l",url:"globals_type.html#index_l"},
{text:"m",url:"globals_type.html#index_m"},
{text:"n",url:"globals_type.html#index_n"},
{text:"p",url:"globals_type.html#index_p"},
{text:"q",url:"globals_type.html#index_q"},
{text:"s",url:"globals_type.html#index_s"},
{text:"t",url:"globals_type.html#index_t"},
{text:"u",url:"globals_type.html#index_u"},
{text:"v",url:"globals_type.html#index_v"}]},
{text:"Enumerations",url:"globals_enum.html",children:[
{text:"b",url:"globals_enum.html#index_b"},
{text:"e",url:"globals_enum.html#index_e"},
{text:"g",url:"globals_enum.html#index_g"},
{text:"h",url:"globals_enum.html#index_h"},
{text:"p",url:"globals_enum.html#index_p"},
{text:"r",url:"globals_enum.html#index_r"}]},
{text:"Enumerator",url:"globals_eval.html",children:[
{text:"b",url:"globals_eval.html#index_b"},
{text:"c",url:"globals_eval.html#index_c"},
{text:"d",url:"globals_eval.html#index_d"},
{text:"e",url:"globals_eval.html#index_e"},
{text:"f",url:"globals_eval.html#index_f"},
{text:"g",url:"globals_eval.html#index_g"},
{text:"h",url:"globals_eval.html#index_h"},
{text:"i",url:"globals_eval.html#index_i"},
{text:"m",url:"globals_eval.html#index_m"},
{text:"p",url:"globals_eval.html#index_p"},
{text:"q",url:"globals_eval.html#index_q"},
{text:"r",url:"globals_eval.html#index_r"},
{text:"s",url:"globals_eval.html#index_s"},
{text:"t",url:"globals_eval.html#index_t"},
{text:"u",url:"globals_eval.html#index_u"}]},
{text:"Macros",url:"globals_defs.html",children:[
{text:"_",url:"globals_defs.html#index__"},
{text:"a",url:"globals_defs_a.html#index_a"},
{text:"b",url:"globals_defs_b.html#index_b"},
{text:"c",url:"globals_defs_c.html#index_c"},
{text:"d",url:"globals_defs_d.html#index_d"},
{text:"e",url:"globals_defs_e.html#index_e"},
{text:"f",url:"globals_defs_f.html#index_f"},
{text:"g",url:"globals_defs_g.html#index_g"},
{text:"h",url:"globals_defs_h.html#index_h"},
{text:"i",url:"globals_defs_i.html#index_i"},
{text:"k",url:"globals_defs_k.html#index_k"},
{text:"l",url:"globals_defs_l.html#index_l"},
{text:"m",url:"globals_defs_m.html#index_m"},
{text:"n",url:"globals_defs_n.html#index_n"},
{text:"o",url:"globals_defs_o.html#index_o"},
{text:"p",url:"globals_defs_p.html#index_p"},
{text:"r",url:"globals_defs_r.html#index_r"},
{text:"s",url:"globals_defs_s.html#index_s"},
{text:"t",url:"globals_defs_t.html#index_t"},
{text:"u",url:"globals_defs_u.html#index_u"},
{text:"v",url:"globals_defs_v.html#index_v"},
{text:"w",url:"globals_defs_w.html#index_w"},
{text:"x",url:"globals_defs_x.html#index_x"},
{text:"y",url:"globals_defs_y.html#index_y"},
{text:"z",url:"globals_defs_z.html#index_z"}]}]}]}]}

==> bullet-docs-3.25-3-aarch64.pkg.tar.xz: usr/share/doc/bullet/html/menudata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var menudata={children:[
{text:"Main Page",url:"index.html"},
{text:"Namespaces",url:"namespaces.html",children:[
{text:"Namespace List",url:"namespaces.html"},
{text:"Namespace Members",url:"namespacemembers.html",children:[
{text:"All",url:"namespacemembers.html"},
{text:"Functions",url:"namespacemembers_func.html"},
{text:"Variables",url:"namespacemembers_vars.html"},
{text:"Typedefs",url:"namespacemembers_type.html"},
{text:"Enumerations",url:"namespacemembers_enum.html"},
{text:"Enumerator",url:"namespacemembers_eval.html"}]}]},
{text:"Classes",url:"annotated.html",children:[
{text:"Class List",url:"annotated.html"},
{text:"Class Hierarchy",url:"inherits.html"},
{text:"Class Members",url:"functions.html",children:[
{text:"All",url:"functions.html",children:[
{text:"_",url:"functions.html#index__5F"},
{text:"a",url:"functions_a.html#index_a"},
{text:"b",url:"functions_b.html#index_b"},
{text:"c",url:"functions_c.html#index_c"},
{text:"d",url:"functions_d.html#index_d"},
{text:"e",url:"functions_e.html#index_e"},
{text:"f",url:"functions_f.html#index_f"},
{text:"g",url:"functions_g.html#index_g"},
{text:"h",url:"functions_h.html#index_h"},
{text:"i",url:"functions_i.html#index_i"},
{text:"j",url:"functions_j.html#index_j"},
{text:"k",url:"functions_k.html#index_k"},
{text:"l",url:"functions_l.html#index_l"},
{text:"m",url:"functions_m.html#index_m"},
{text:"n",url:"functions_n.html#index_n"},
{text:"o",url:"functions_o.html#index_o"},
{text:"p",url:"functions_p.html#index_p"},
{text:"q",url:"functions_q.html#index_q"},
{text:"r",url:"functions_r.html#index_r"},
{text:"s",url:"functions_s.html#index_s"},
{text:"t",url:"functions_t.html#index_t"},
{text:"u",url:"functions_u.html#index_u"},
{text:"v",url:"functions_v.html#index_v"},
{text:"w",url:"functions_w.html#index_w"},
{text:"x",url:"functions_x.html#index_x"},
{text:"y",url:"functions_y.html#index_y"},
{text:"z",url:"functions_z.html#index_z"},
{text:"~",url:"functions_~.html#index__7E"}]},
{text:"Functions",url:"functions_func.html",children:[
{text:"_",url:"functions_func.html#index__5F"},
{text:"a",url:"functions_func_a.html#index_a"},
{text:"b",url:"functions_func_b.html#index_b"},
{text:"c",url:"functions_func_c.html#index_c"},
{text:"d",url:"functions_func_d.html#index_d"},
{text:"e",url:"functions_func_e.html#index_e"},
{text:"f",url:"functions_func_f.html#index_f"},
{text:"g",url:"functions_func_g.html#index_g"},
{text:"h",url:"functions_func_h.html#index_h"},
{text:"i",url:"functions_func_i.html#index_i"},
{text:"j",url:"functions_func_j.html#index_j"},
{text:"k",url:"functions_func_k.html#index_k"},
{text:"l",url:"functions_func_l.html#index_l"},
{text:"m",url:"functions_func_m.html#index_m"},
{text:"n",url:"functions_func_n.html#index_n"},
{text:"o",url:"functions_func_o.html#index_o"},
{text:"p",url:"functions_func_p.html#index_p"},
{text:"q",url:"functions_func_q.html#index_q"},
{text:"r",url:"functions_func_r.html#index_r"},
{text:"s",url:"functions_func_s.html#index_s"},
{text:"t",url:"functions_func_t.html#index_t"},
{text:"u",url:"functions_func_u.html#index_u"},
{text:"v",url:"functions_func_v.html#index_v"},
{text:"w",url:"functions_func_w.html#index_w"},
{text:"x",url:"functions_func_x.html#index_x"},
{text:"y",url:"functions_func_y.html#index_y"},
{text:"z",url:"functions_func_z.html#index_z"},
{text:"~",url:"functions_func_~.html#index__7E"}]},
{text:"Variables",url:"functions_vars.html",children:[
{text:"_",url:"functions_vars.html#index__5F"},
{text:"a",url:"functions_vars_a.html#index_a"},
{text:"b",url:"functions_vars_b.html#index_b"},
{text:"c",url:"functions_vars_c.html#index_c"},
{text:"d",url:"functions_vars_d.html#index_d"},
{text:"e",url:"functions_vars_e.html#index_e"},
{text:"f",url:"functions_vars_f.html#index_f"},
{text:"g",url:"functions_vars_g.html#index_g"},
{text:"h",url:"functions_vars_h.html#index_h"},
{text:"i",url:"functions_vars_i.html#index_i"},
{text:"j",url:"functions_vars_j.html#index_j"},
{text:"k",url:"functions_vars_k.html#index_k"},
{text:"l",url:"functions_vars_l.html#index_l"},
{text:"m",url:"functions_vars_m.html#index_m"},
{text:"n",url:"functions_vars_n.html#index_n"},
{text:"o",url:"functions_vars_o.html#index_o"},
{text:"p",url:"functions_vars_p.html#index_p"},
{text:"r",url:"functions_vars_r.html#index_r"},
{text:"s",url:"functions_vars_s.html#index_s"},
{text:"t",url:"functions_vars_t.html#index_t"},
{text:"u",url:"functions_vars_u.html#index_u"},
{text:"v",url:"functions_vars_v.html#index_v"},
{text:"w",url:"functions_vars_w.html#index_w"},
{text:"x",url:"functions_vars_x.html#index_x"},
{text:"y",url:"functions_vars_y.html#index_y"},
{text:"z",url:"functions_vars_z.html#index_z"}]},
{text:"Typedefs",url:"functions_type.html",children:[
{text:"_",url:"functions_type.html#index__5F"},
{text:"b",url:"functions_type.html#index_b"},
{text:"c",url:"functions_type.html#index_c"},
{text:"i",url:"functions_type.html#index_i"},
{text:"o",url:"functions_type.html#index_o"},
{text:"p",url:"functions_type.html#index_p"},
{text:"r",url:"functions_type.html#index_r"},
{text:"s",url:"functions_type.html#index_s"},
{text:"t",url:"functions_type.html#index_t"},
{text:"v",url:"functions_type.html#index_v"}]},
{text:"Enumerations",url:"functions_enum.html",children:[
{text:"_",url:"functions_enum.html#index__5F"},
{text:"a",url:"functions_enum.html#index_a"},
{text:"b",url:"functions_enum.html#index_b"},
{text:"c",url:"functions_enum.html#index_c"},
{text:"d",url:"functions_enum.html#index_d"},
{text:"e",url:"functions_enum.html#index_e"},
{text:"f",url:"functions_enum.html#index_f"},
{text:"o",url:"functions_enum.html#index_o"},
{text:"s",url:"functions_enum.html#index_s"}]},
{text:"Enumerator",url:"functions_eval.html",children:[
{text:"a",url:"functions_eval.html#index_a"},
{text:"b",url:"functions_eval.html#index_b"},
{text:"c",url:"functions_eval.html#index_c"},
{text:"d",url:"functions_eval.html#index_d"},
{text:"e",url:"functions_eval.html#index_e"},
{text:"f",url:"functions_eval.html#index_f"},
{text:"g",url:"functions_eval.html#index_g"},
{text:"i",url:"functions_eval.html#index_i"},
{text:"j",url:"functions_eval.html#index_j"},
{text:"k",url:"functions_eval.html#index_k"},
{text:"l",url:"functions_eval.html#index_l"},
{text:"m",url:"functions_eval.html#index_m"},
{text:"n",url:"functions_eval.html#index_n"},
{text:"o",url:"functions_eval.html#index_o"},
{text:"p",url:"functions_eval.html#index_p"},
{text:"r",url:"functions_eval.html#index_r"},
{text:"s",url:"functions_eval.html#index_s"},
{text:"t",url:"functions_eval.html#index_t"},
{text:"v",url:"functions_eval.html#index_v"}]},
{text:"Related Functions",url:"functions_rela.html"}]}]},
{text:"Files",url:"files.html",children:[
{text:"File List",url:"files.html"},
{text:"File Members",url:"globals.html",children:[
{text:"All",url:"globals.html",children:[
{text:"_",url:"globals.html#index__5F"},
{text:"a",url:"globals_a.html#index_a"},
{text:"b",url:"globals_b.html#index_b"},
{text:"c",url:"globals_c.html#index_c"},
{text:"d",url:"globals_d.html#index_d"},
{text:"e",url:"globals_e.html#index_e"},
{text:"f",url:"globals_f.html#index_f"},
{text:"g",url:"globals_g.html#index_g"},
{text:"h",url:"globals_h.html#index_h"},
{text:"i",url:"globals_i.html#index_i"},
{text:"k",url:"globals_k.html#index_k"},
{text:"l",url:"globals_l.html#index_l"},
{text:"m",url:"globals_m.html#index_m"},
{text:"n",url:"globals_n.html#index_n"},
{text:"o",url:"globals_o.html#index_o"},
{text:"p",url:"globals_p.html#index_p"},
{text:"q",url:"globals_q.html#index_q"},
{text:"r",url:"globals_r.html#index_r"},
{text:"s",url:"globals_s.html#index_s"},
{text:"t",url:"globals_t.html#index_t"},
{text:"u",url:"globals_u.html#index_u"},
{text:"v",url:"globals_v.html#index_v"},
{text:"w",url:"globals_w.html#index_w"},
{text:"x",url:"globals_x.html#index_x"},
{text:"y",url:"globals_y.html#index_y"},
{text:"z",url:"globals_z.html#index_z"}]},
{text:"Functions",url:"globals_func.html",children:[
{text:"_",url:"globals_func.html#index__5F"},
{text:"a",url:"globals_func_a.html#index_a"},
{text:"b",url:"globals_func_b.html#index_b"},
{text:"c",url:"globals_func_c.html#index_c"},
{text:"d",url:"globals_func_d.html#index_d"},
{text:"e",url:"globals_func_e.html#index_e"},
{text:"f",url:"globals_func_f.html#index_f"},
{text:"g",url:"globals_func_g.html#index_g"},
{text:"h",url:"globals_func_h.html#index_h"},
{text:"i",url:"globals_func_i.html#index_i"},
{text:"l",url:"globals_func_l.html#index_l"},
{text:"m",url:"globals_func_m.html#index_m"},
{text:"n",url:"globals_func_n.html#index_n"},
{text:"o",url:"globals_func_o.html#index_o"},
{text:"p",url:"globals_func_p.html#index_p"},
{text:"q",url:"globals_func_q.html#index_q"},
{text:"r",url:"globals_func_r.html#index_r"},
{text:"s",url:"globals_func_s.html#index_s"},
{text:"t",url:"globals_func_t.html#index_t"},
{text:"u",url:"globals_func_u.html#index_u"},
{text:"v",url:"globals_func_v.html#index_v"},
{text:"w",url:"globals_func_w.html#index_w"},
{text:"z",url:"globals_func_z.html#index_z"}]},
{text:"Variables",url:"globals_vars.html",children:[
{text:"b",url:"globals_vars.html#index_b"},
{text:"c",url:"globals_vars.html#index_c"},
{text:"d",url:"globals_vars.html#index_d"},
{text:"e",url:"globals_vars.html#index_e"},
{text:"g",url:"globals_vars.html#index_g"},
{text:"i",url:"globals_vars.html#index_i"},
{text:"k",url:"globals_vars.html#index_k"},
{text:"n",url:"globals_vars.html#index_n"},
{text:"o",url:"globals_vars.html#index_o"},
{text:"p",url:"globals_vars.html#index_p"},
{text:"s",url:"globals_vars.html#index_s"},
{text:"u",url:"globals_vars.html#index_u"},
{text:"v",url:"globals_vars.html#index_v"}]},
{text:"Typedefs",url:"globals_type.html",children:[
{text:"b",url:"globals_type.html#index_b"},
{text:"c",url:"globals_type.html#index_c"},
{text:"d",url:"globals_type.html#index_d"},
{text:"g",url:"globals_type.html#index_g"},
{text:"h",url:"globals_type.html#index_h"},
{text:"i",url:"globals_type.html#index_i"},
{text:"l",url:"globals_type.html#index_l"},
{text:"m",url:"globals_type.html#index_m"},
{text:"n",url:"globals_type.html#index_n"},
{text:"p",url:"globals_type.html#index_p"},
{text:"q",url:"globals_type.html#index_q"},
{text:"s",url:"globals_type.html#index_s"},
{text:"t",url:"globals_type.html#index_t"},
{text:"u",url:"globals_type.html#index_u"},
{text:"v",url:"globals_type.html#index_v"}]},
{text:"Enumerations",url:"globals_enum.html",children:[
{text:"b",url:"globals_enum.html#index_b"},
{text:"e",url:"globals_enum.html#index_e"},
{text:"g",url:"globals_enum.html#index_g"},
{text:"h",url:"globals_enum.html#index_h"},
{text:"p",url:"globals_enum.html#index_p"},
{text:"r",url:"globals_enum.html#index_r"}]},
{text:"Enumerator",url:"globals_eval.html",children:[
{text:"b",url:"globals_eval.html#index_b"},
{text:"c",url:"globals_eval_c.html#index_c"},
{text:"d",url:"globals_eval_d.html#index_d"},
{text:"e",url:"globals_eval_e.html#index_e"},
{text:"f",url:"globals_eval_f.html#index_f"},
{text:"g",url:"globals_eval_g.html#index_g"},
{text:"h",url:"globals_eval_h.html#index_h"},
{text:"i",url:"globals_eval_i.html#index_i"},
{text:"m",url:"globals_eval_m.html#index_m"},
{text:"p",url:"globals_eval_p.html#index_p"},
{text:"q",url:"globals_eval_q.html#index_q"},
{text:"r",url:"globals_eval_r.html#index_r"},
{text:"s",url:"globals_eval_s.html#index_s"},
{text:"t",url:"globals_eval_t.html#index_t"},
{text:"u",url:"globals_eval_u.html#index_u"}]},
{text:"Macros",url:"globals_defs.html",children:[
{text:"_",url:"globals_defs.html#index__5F"},
{text:"a",url:"globals_defs_a.html#index_a"},
{text:"b",url:"globals_defs_b.html#index_b"},
{text:"c",url:"globals_defs_c.html#index_c"},
{text:"d",url:"globals_defs_d.html#index_d"},
{text:"e",url:"globals_defs_e.html#index_e"},
{text:"f",url:"globals_defs_f.html#index_f"},
{text:"g",url:"globals_defs_g.html#index_g"},
{text:"h",url:"globals_defs_h.html#index_h"},
{text:"i",url:"globals_defs_i.html#index_i"},
{text:"k",url:"globals_defs_k.html#index_k"},
{text:"l",url:"globals_defs_l.html#index_l"},
{text:"m",url:"globals_defs_m.html#index_m"},
{text:"n",url:"globals_defs_n.html#index_n"},
{text:"o",url:"globals_defs_o.html#index_o"},
{text:"p",url:"globals_defs_p.html#index_p"},
{text:"r",url:"globals_defs_r.html#index_r"},
{text:"s",url:"globals_defs_s.html#index_s"},
{text:"t",url:"globals_defs_t.html#index_t"},
{text:"u",url:"globals_defs_u.html#index_u"},
{text:"v",url:"globals_defs_v.html#index_v"},
{text:"w",url:"globals_defs_w.html#index_w"},
{text:"x",url:"globals_defs_x.html#index_x"},
{text:"y",url:"globals_defs_y.html#index_y"},
{text:"z",url:"globals_defs_z.html#index_z"}]}]}]}]}
